==> konclude_0.6.2+939~dfsg.orig.tar.xz: Konclude-0.6.2-939/Source/Control/Command/Instructions/CCreateKnowledgeBaseRevisionUpdateCommand.h <==
/*
 *		Copyright (C) 2013-2015, 2019 by the Konclude Developer Team.
 *
 *		This file is part of the reasoning system Konclude.
 *		For details and support, see <http://konclude.com/>.
 *
 *		Konclude is free software: you can redistribute it and/or modify
 *		it under the terms of version 3 of the GNU Lesser General Public
 *		License (LGPLv3) as published by the Free Software Foundation.
 *
 *		Konclude is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *		GNU (Lesser) General Public License for more details.
 *
 *		You should have received a copy of the GNU (Lesser) General Public
 *		License along with Konclude. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef KONCLUDE_Control_COMMAND_CCREATEKNOWLEDGEBASEREVISIONUPDATECOMMAND_H
#define KONCLUDE_Control_COMMAND_CCREATEKNOWLEDGEBASEREVISIONUPDATECOMMAND_H

// Libraries includes
#include <QString>

// Namespace includes
#include "CKnowledgeBaseRevisionCommandProvider.h"
#include "CKnowledgeBaseCommand.h"

// Other includes
#include "Control/Command/CommandSettings.h"
#include "Control/Command/CCommand.h"
#include "Control/Command/CPreconditionCommand.h"


// Logger includes
#include "Logger/CLogger.h"

using namespace Konclude::Logger;


namespace Konclude {

	namespace Control {

		namespace Command {

			namespace Instructions {

				/*! 
				 *
				 *		\class		CCreateKnowledgeBaseRevisionUpdateCommand
				 *		\author		Andreas Steigmiller
				 *		\version	0.1
				 *		\brief		TODO
				 *
				 */
				class CCreateKnowledgeBaseRevisionUpdateCommand : public CKnowledgeBaseCommand, public CKnowledgeBaseRevisionCommandProvider {
					// public methods
					public:
						//! Constructor
						CCreateKnowledgeBaseRevisionUpdateCommand(const QString &knowledgeBaseNameString, CCommand *parentSuperCommand = 0);
						CCreateKnowledgeBaseRevisionUpdateCommand(const QString &knowledgeBaseNameString, bool createIfNotExist, CCommand *parentSuperCommand = 0);

						//! Destructor
						virtual ~CCreateKnowledgeBaseRevisionUpdateCommand();

						virtual qint64 getCommandTag();
						virtual QString getBriefCommandDescription();

						virtual QString getKnowledgeBaseName();
						virtual COntologyRevision *getOntologyRevision();
						virtual CCreateKnowledgeBaseRevisionUpdateCommand *setOntologyRevision(COntologyRevision *ontologyRevision);
						virtual CCommand *getCommand();

						bool requireCreateIfNotExist();

					// protected methods
					protected:

					// protected variables
					protected:
						bool mCreateIfNotExist;
						QString kbString;
						COntologyRevision *onRev;

					// private methods
					private:

					// private variables
					private:

				};

			}; // end namespace Instructions

		}; // end namespace Command

	}; // end namespace Control

}; // end namespace Konclude

#endif // KONCLUDE_Control_COMMAND_CCREATEKNOWLEDGEBASEREVISIONUPDATECOMMAND_H

==> konclude_0.7.0+1137~dfsg.orig.tar.xz: Konclude-0.7.0-1137/Source/Control/Command/Instructions/CCreateKnowledgeBaseRevisionUpdateCommand.h <==
/*
 *		Copyright (C) 2013-2015, 2019 by the Konclude Developer Team.
 *
 *		This file is part of the reasoning system Konclude.
 *		For details and support, see <http://konclude.com/>.
 *
 *		Konclude is free software: you can redistribute it and/or modify
 *		it under the terms of version 3 of the GNU Lesser General Public
 *		License (LGPLv3) as published by the Free Software Foundation.
 *
 *		Konclude is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *		GNU (Lesser) General Public License for more details.
 *
 *		You should have received a copy of the GNU (Lesser) General Public
 *		License along with Konclude. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef KONCLUDE_Control_COMMAND_CCREATEKNOWLEDGEBASEREVISIONUPDATECOMMAND_H
#define KONCLUDE_Control_COMMAND_CCREATEKNOWLEDGEBASEREVISIONUPDATECOMMAND_H

// Libraries includes
#include <QString>

// Namespace includes
#include "CKnowledgeBaseRevisionCommandProvider.h"
#include "CKnowledgeBaseCommand.h"

// Other includes
#include "Control/Command/CommandSettings.h"
#include "Control/Command/CCommand.h"
#include "Control/Command/CPreconditionCommand.h"


// Logger includes
#include "Logger/CLogger.h"

using namespace Konclude::Logger;


namespace Konclude {

	namespace Control {

		namespace Command {

			namespace Instructions {

				/*! 
				 *
				 *		\class		CCreateKnowledgeBaseRevisionUpdateCommand
				 *		\author		Andreas Steigmiller
				 *		\version	0.1
				 *		\brief		TODO
				 *
				 */
				class CCreateKnowledgeBaseRevisionUpdateCommand : public CKnowledgeBaseCommand, public CKnowledgeBaseRevisionCommandProvider {
					// public methods
					public:
						//! Constructor
						CCreateKnowledgeBaseRevisionUpdateCommand(const QString &knowledgeBaseNameString, CCommand *parentSuperCommand = 0);
						CCreateKnowledgeBaseRevisionUpdateCommand(const QString &knowledgeBaseNameString, bool createIfNotExist, CCommand *parentSuperCommand = 0);
						CCreateKnowledgeBaseRevisionUpdateCommand(const QString &knowledgeBaseNameString, bool createIfNotExist, bool reportErrorIfNotExists, CCommand *parentSuperCommand = 0);

						//! Destructor
						virtual ~CCreateKnowledgeBaseRevisionUpdateCommand();

						virtual qint64 getCommandTag();
						virtual QString getBriefCommandDescription();

						virtual QString getKnowledgeBaseName();
						virtual COntologyRevision *getOntologyRevision();
						virtual CCreateKnowledgeBaseRevisionUpdateCommand *setOntologyRevision(COntologyRevision *ontologyRevision);
						virtual CCommand *getCommand();

						bool requireCreateIfNotExist();
						bool reportErrorCreateIfNotExist();

					// protected methods
					protected:

					// protected variables
					protected:
						bool mCreateIfNotExist;
						bool mReportErrorIfNotExists;
						QString kbString;
						COntologyRevision *onRev;

					// private methods
					private:

					// private variables
					private:

				};

			}; // end namespace Instructions

		}; // end namespace Command

	}; // end namespace Control

}; // end namespace Konclude

#endif // KONCLUDE_Control_COMMAND_CCREATEKNOWLEDGEBASEREVISIONUPDATECOMMAND_H
